@@ -15,7 +15,6 @@
 #'                no plot is created.
 #' @param cutoff The cutoff of the y-axis on the plot (a number between 0 and 1, default is 1).
 #' @param start The lag that the extremogram plots starts at (an integer not greater than \code{maxlag}, default is 0).
-#' @param ... further arguments: plot and axis names.
 #' @return Cross extremogram values and a plot (if requested).
 #' @references \enumerate{
 #'             \item Davis, R. A., Mikosch, T., & Cribben, I. (2012). Towards estimating extremal 
@@ -43,7 +42,7 @@
 #' extremogram2(data, quant, quant, maxlag, type, 1, 1, 0)
 #' @export 
 
-extremogram2 = function(a, quant1, quant2, maxlag, type, ploting=1, cutoff=1, start=0, ...) {
+extremogram2 = function(a, quant1, quant2, maxlag, type, ploting=1, cutoff=1, start=0) {
   
   x=a[,1]
   y=a[,2]
@@ -53,35 +52,38 @@ extremogram2 = function(a, quant1, quant2, maxlag, type, ploting=1, cutoff=1, st
   if (type == 1) { 
     for ( i in 1:maxlag) {
       rhohat[i]=length((1:(n-i))[x[1:(n-i+1)] > level1 & y[i:n]> level2])
-      rhohat[i]=rhohat[i]/length((1:n)[x[1:(n-i+1)]>level1])
+      rhohat[i]=rhohat[i]/length((1:(n-i))[x[1:(n-i+1)]>level1])
     }
   }
   else
     if (type == 2) {
       for ( i in 1:maxlag) {
         rhohat[i]=length((1:(n-i))[x[1:(n-i+1)] < level1 & y[i:n]< level2])
-        rhohat[i]=rhohat[i]/length((1:n)[x[1:(n-i+1)] < level1])
+        rhohat[i]=rhohat[i]/length((1:(n-i))[x[1:(n-i+1)] < level1])
       }
     }
   else
     if (type == 3) {
       for ( i in 1:maxlag) {
         rhohat[i]=length((1:(n-i))[x[1:(n-i+1)] < level1 & y[i:n]> level2])
-        rhohat[i]=rhohat[i]/length((1:n)[x[1:(n-i+1)] < level1])
+        rhohat[i]=rhohat[i]/length((1:(n-i))[x[1:(n-i+1)] < level1])
       }
     }
   else
     if (type == 4) {
       for ( i in 1:maxlag) {
         rhohat[i]=length((1:(n-i))[x[1:(n-i+1)] > level1 & y[i:n]< level2])
-        rhohat[i]=rhohat[i]/length((1:n)[x[1:(n-i+1)] > level1])
+        rhohat[i]=rhohat[i]/length((1:(n-i))[x[1:(n-i+1)] > level1])
       }
     }
   
   
   
   if (ploting == 1) {
-    plot.extr(rhohat, start = start, maxlag = maxlag, cutoff = cutoff, ...) 
+    plot((start:(maxlag-1)),rhohat[(start+1):maxlag],type="n",xlab="lag",ylab="extremogram",ylim=c(0,cutoff))
+    lines((start:(maxlag-1)),rhohat[(start+1):maxlag],col=1,lwd=1,type="h")
+    abline((0:(maxlag-1)),0,col=1,lwd=1)
+    
   }
   
   return(rhohat)	
